ruyaml
======

``ruyaml`` package is a fork of ``ruamel.yaml`` aimed to made in order to
secure the future of the library, mainly by having a pool of maintainers.

Notes
=====

- Current version is a drop-in dependency replacement for "ruamel.yaml"
  package and will install `ruamel.yaml` python module. As long this is still
  true keep in mind not to install `ruamel.yaml` package.
- python3.6 is the minimal version of python supported
